/*
 * file CcHyperlink.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM 
 * com.ibm.rational.wvcm.stp.cc.CcHyperlink
 *
 *  Copyright IBM Corporation 2007, 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */
package com.ibm.rational.wvcm.stp.cc;

import static com.ibm.rational.wvcm.stpex.StpExBase.PROPERTY_NAMESPACE;

import javax.wvcm.WvcmException;
import javax.wvcm.PropertyNameList.PropertyName;

/**
 * A proxy for a ClearCase hyperlink object.
 * <p>
 * Conceptually, a hyperlink is an arrow from one VOB-database object (version, branch, element, 
 * VOB symbolic link or VOB) to another.  A merge arrow is a special kind of hyperlink.
 * </p>
 * <p>
 * For more information about hyperlinks, see the ClearCase "Guide to Managing Software Projects"
 * manual, and the cleartool man page "mkhlink".
 * </p>
 */
public interface CcHyperlink extends CcVobResource
{
    /**
     * The resource at the "from" end of the hyperlink
     */
    PropertyName<CcResource> FROM_RESOURCE =
        new PropertyName<CcResource>(PROPERTY_NAMESPACE,
                                     "hlink-from-resource");
   
    /**
     * Get the value of this hyperlink instance's {@link #FROM_RESOURCE} property.
     * 
     * @return resource hyperlink instance points from
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property or 
     *             the resource is unavailable/does not exist
     */
    CcResource getFromResource() throws WvcmException;

    /**
     * The text associated with the "from" end of the hyperlink.
     */
    PropertyName<String> FROM_TEXT =
        new PropertyName<String>(PROPERTY_NAMESPACE,
                                     "hlink-from-text");
    
    /**
     * Get the value of this hyperlink instance's {@link #FROM_TEXT} property.
     * 
     * @return String containing text associated with the "from" end of the hyperlink.
     *         Will be <code>null</code> if no text was specified during hyperlink creation.
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property or 
     *             the resource is unavailable/does not exist
     */
    String getFromText() throws WvcmException;
    
    /**
     * The resource at the "to" end of the hyperlink
     */
    PropertyName<CcResource> TO_RESOURCE =
        new PropertyName<CcResource>(PROPERTY_NAMESPACE,
                                     "hlink-to-resource");
   
    /**
     * Get the value of this hyperlink instance's {@link #TO_RESOURCE} property.
     * 
     * @return resource hyperlink instance points to, or null if single-ended hyperlink
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property or 
     *             the resource is unavailable/does not exist
     */
    CcResource getToResource() throws WvcmException;

    /**
     * The text associated with the "to" end of the hyperlink.
     */
    PropertyName<String> TO_TEXT =
        new PropertyName<String>(PROPERTY_NAMESPACE,
                                     "hlink-to-text");
    
    /**
     * Get the value of this hyperlink instance's {@link #TO_TEXT} property.
     * 
     * @return String containing text associated with the "to" end of the hyperlink.
     *         Will be <code>null</code> if no text was specified during hyperlink creation.
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property or 
     *             the resource is unavailable/does not exist
     */
    String getToText() throws WvcmException;
    
    /**
     * The hyperlink type of which this hyperlink is an instance.
     */
    PropertyName<CcHyperlinkType> TYPE =
        new PropertyName<CcHyperlinkType>(PROPERTY_NAMESPACE,
                                          "hlink-type");

    /**
     * Get the value of this hyperlink instance's {@link #TYPE} property.
     * 
     * @return hyperlink instance's hyperlink type
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property.
     */
    CcHyperlinkType getType() throws WvcmException;

}
