/*
* file CcPermissions.java
*
* Licensed Materials - Property of IBM
* Restricted Materials of IBM
* 
* com.ibm.rational.wvcm.stp.cc.CcPermissions
*
*  Copyright IBM Corporation 2008.  All Rights Reserved. 
* Note to U.S. Government Users Restricted Rights:  Use, duplication or  
* disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
*/

package com.ibm.rational.wvcm.stp.cc;

import javax.wvcm.WvcmException;

/**
 * <p>
 * Interface which provides a method of distinguishing the aggregated
 * results returned by a {@link CcElement#PERMISSIONS} property request.
 * </p>
 */
public interface CcPermissions {
    
    /**
     * Interface for accessing individual permissions (read, write,
     * and execute) supported on ClearCase objects.
     * 
     */
    public interface Permissions {
        /** 
         * Gets read permission
         * @return true if enabled, otherwise false.
         */
        public boolean getRead();
        /** 
         * Gets write permission
         * @return true if enabled, otherwise false.
         */
        public boolean getWrite();
        /** 
         * Gets execute permission
         * @return true if enabled, otherwise false.
         */
        public boolean getExecute();
        /**
         * Sets read permission 
         * @param t  true to enable, false to disable.
         */
        public void setRead(boolean t);
        /**
         * Sets write permission 
         * @param t  true to enable, false to disable.
         */
        public void setWrite(boolean t);
        /**
         * Sets execute permission 
         * @param t  true to enable, false to disable.
         */
        public void setExecute(boolean t);
    }
    
    /**
     * Gets the user name.
     * @return user name
     * @throws WvcmException
     */
    public String getUserName() throws WvcmException;
    
    /**
     * Gets the group name.
     * @return group name
     * @throws WvcmException
     */
    public String getGroupName() throws WvcmException;
    
    /**
     * Gets the permissions for user.
     * @return permissions
     * @throws WvcmException
     */
    public Permissions getUserPermissions() throws WvcmException;
    
    /**
     * Gets the permissions for group.
     * @return permissions
     * @throws WvcmException
     */
    public Permissions getGroupPermissions() throws WvcmException;
    
    /**
     * Gets the permissions for other.
     * @return permissions
     * @throws WvcmException
     */
    public Permissions getOtherPermissions() throws WvcmException;
        
    /**
     * Gets the setuid setting.
     * @return permissions
     * @throws WvcmException
     */
    public boolean getSetuid() throws WvcmException;
    
    /**
     * Gets the setgid setting.
     * @return permissions
     * @throws WvcmException
     */
    public boolean getSetgid() throws WvcmException;
    
    /**
     * Sets the user name.
     * @param name
     * @throws WvcmException
     */
    public void setUserName(String name) throws WvcmException;
    
    /**
     * Sets the group name.
     * @param name
     * @throws WvcmException
     */
    public void setGroupName(String name) throws WvcmException;
    
    /**
     * Sets the setuid permission.
     * @param value
     * @throws WvcmException
     */
    public void setSetuid(boolean value) throws WvcmException;
    
    /**
     * Sets the setgid permission.
     * @param value
     * @throws WvcmException
     */
    public void setSetgid(boolean value) throws WvcmException;
    
    /**
     * Sets permissions for user.
     * @param permissions
     * @throws WvcmException
     */
    public void setUserPermissions(Permissions permissions) throws WvcmException;
    
    /** 
     * Sets permissions for group.
     * @param permissions
     * @throws WvcmException
     */
    public void setGroupPermissions(Permissions permissions) throws WvcmException;
    
    /**
     * Sets permissions for other.
     * @param permissions
     * @throws WvcmException
     */
    public void setOtherPermissions(Permissions permissions) throws WvcmException;

    /**
     * @deprecated For internal use only
     */
    public String toXml() throws WvcmException;
    
}
